@@ -314,7 +314,7 @@ module Exploit::Remote::HttpClient
         print_line('#' * 20)
         print_line('# Response:')
         print_line('#' * 20)
-        print_line(res.to_s)
+        print_line(res.to_terminal_output)
       end
 
       res
@@ -360,7 +360,7 @@ module Exploit::Remote::HttpClient
         print_line('#' * 20)
         print_line('# Response:')
         print_line('#' * 20)
-        print_line(res.to_s)
+        print_line(res.to_terminal_output)
       end
       disconnect(c)
       res
@@ -463,10 +463,17 @@ module Exploit::Remote::HttpClient
   end
 
   # Returns the complete URI as string including the scheme, port and host
-  def full_uri
+  def full_uri(custom_uri = nil)
     uri_scheme = ssl ? 'https' : 'http'
-    uri_port = rport.to_s == '80' ? '' : ":#{rport}"
-    uri = normalize_uri(target_uri.to_s)
+
+    if (rport == 80 && !ssl) || (rport == 443 && ssl)
+      uri_port = ''
+    else
+      uri_port = ":#{rport}"
+    end
+
+    uri = normalize_uri(custom_uri || target_uri.to_s)
+
     "#{uri_scheme}://#{rhost}#{uri_port}#{uri}"
   end
 
@@ -501,6 +508,68 @@ module Exploit::Remote::HttpClient
     end
   end
 
+  #
+  # Returns a hash of request opts from a URL string
+  def request_opts_from_url(url)
+    # verify and extract components from the URL
+    begin
+      tgt = URI.parse(url)
+      raise 'Invalid URL' unless tgt.scheme =~ %r{https?}
+      raise 'Invalid URL' if tgt.host.to_s.eql? ''
+    rescue => e
+      print_error "Could not parse URL: #{e}"
+      return nil
+    end
+
+    opts = { 'rhost' => tgt.host, 'rport' => tgt.port, 'uri' => tgt.request_uri }
+    opts['SSL'] = true if tgt.scheme == 'https'
+    if tgt.query and tgt.query.size > 13
+      # Assming that this is going to be mostly used for GET requests as string -> req
+      opts['vars_get'] = {}
+      tgt.query.split('&').each do |pair|
+        k,v = pair.split('=',2)
+        opts['vars_get'][k] = v
+      end
+    end
+    return opts
+  end
+
+  #
+  # Returns response from a simple URL call
+  def request_url(url, keepalive = false)
+    opts = request_opts_from_url(url)
+    return nil if opts.nil?
+    res = send_request_raw(opts)
+    disconnect unless keepalive
+    return res
+  end
+
+  #
+  # Downloads a URL
+  def download(url)
+    print_status "Downloading '#{url}'"
+
+    begin
+      target = URI.parse url
+      raise 'Invalid URL' unless target.scheme =~ /https?/
+      raise 'Invalid URL' if target.host.to_s.eql? ''
+    rescue => e
+      print_error "Could not parse URL: #{e}"
+      return nil
+    end
+
+    res = request_url(url)
+
+    unless res
+      print_error 'Connection failed'
+      return nil
+    end
+
+    print_status "- HTTP #{res.code} - #{res.body.length} bytes"
+
+    res.code == 200 ? res.body : nil
+  end
+
   # removes HTML tags from a provided string.
   # The string is html-unescaped before the tags are removed
   # Leading whitespaces and double linebreaks are removed too
@@ -765,6 +834,16 @@ module Exploit::Remote::HttpClient
     fprint[:signature]
   end
 
+  def service_details
+    {
+      origin_type: :service,
+      protocol: 'tcp',
+      service_name: (ssl ? 'https' : 'http'),
+      address: rhost,
+      port: rport
+    }
+  end
+
 protected
 
   attr_accessor :client
