@@ -32,9 +32,9 @@ class MetasploitModule < Msf::Exploit::Remote
       saved RETURN address at offset 0x6c is overwritten by the data written past the buffer.
 
       To ensure we can perform arbitrary code execution we must we provide a valid pointer at
-      0x74 which is used as a argument for the called function at 0x675751ED as a id file
+      0x74 which is used as an argument for the called function at 0x675751ED as an id file
       extension parameter. Once the caller regains control we will reach our RETURN. The Ret
-      instruction will be used to pop the overwritten saved return address which was currupted.
+      instruction will be used to pop the overwritten saved return address which was corrupted.
 
       This exploit has been written to bypass 2 mitigations DEP and ASLR on a Windows platform.
 
