@@ -1,12 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
-
-
 ###
 #
 # This class implements a "nop" generator for PHP payloads
@@ -29,5 +25,4 @@ class MetasploitModule < Msf::Nop
     # Default to just spaces for now
     " " * length
   end
-
 end
