@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/handler/bind_tcp'
 require 'msf/core/payload/linux/bind_tcp'
 
@@ -27,5 +26,4 @@ module MetasploitModule
       'Stager'      => { 'RequiresMidstager' => true }
     ))
   end
-
 end
