@@ -1,9 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-require 'msf/core'
 require 'msf/core/handler/reverse_http'
 require 'msf/core/payload/multi/reverse_http'
 
@@ -27,5 +26,4 @@ module MetasploitModule
       'Stager'      => {'Payload' => ''},
       'Convention'  => 'http'))
   end
-
 end
